## Goal
Build a timeseries forcasting model for bitcoin close price.

## Evaluation metric
Root-Mean-Squared-Error (RMSE) between the logarithm of the predicted value and the logarithm of the observed price.